@@ -64,6 +64,10 @@
 ( cd opt/kde/share/doc/HTML/en/kreversi ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kblackbox ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kblackbox ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/ksmiletris ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/ksmiletris ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kmahjongg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kmahjongg ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kfouleggs ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/klickety ; rm -rf common )
@@ -74,7 +78,5 @@
 ( cd opt/kde/share/doc/HTML/en/kenolaba ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/ksokoban ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/ksokoban ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kdegames-apidocs ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kdegames-apidocs ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/atlantik ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/atlantik ; ln -sf /opt/kde/share/doc/HTML/en/common common )
